* Output options: all can be turned on/off by adding or removing the NO;
* page number, date, centering, or page breaks, page length and width;
OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=MAX;
* Eliminate SAS default titles and names of tables in output (TRACE ON to show);
TITLE; ODS TRACE OFF; ODS LISTING;

***********************************************************************************;
*******                  BEGIN DATA MANIPULATION FOR EXAMPLE 7              *******;
*******                  CHANGE "filesave" to your directory                *******;
***********************************************************************************;

* Defining global variable for file location to be replaced in code below;
%LET filesave= C:\Dropbox\Example Data\School Data;
* Location for SAS files for these models (uses macro variable filesave);
LIBNAME filesave "&filesave.";
    
* Importing data into work library;
DATA work.grade10; SET filesave.grade10school; 
LABEL	studentID=	"studentID: Student ID number"
		schoolID=	"schoolID: School ID number"
		frlunch=	"frlunch: 0=No, 1=Free/Reduced Lunch"
		math=		"math: Math Test Score Outcome";
	* Selecting cases that are complete for analysis variables;
	IF NMISS(studentID, schoolID, frlunch, math)>0 THEN DELETE;
RUN;

* Getting school means;
PROC SORT DATA=work.grade10; BY schoolID studentID; RUN;
PROC MEANS NOPRINT N DATA=work.grade10; 
	 BY schoolID;
	 VAR frlunch math;
	 OUTPUT OUT=work.SchoolMeans 
		    MEAN(frlunch math)= SMfrlunch SMmath; 
RUN;

* Labeling new school mean variables;
DATA work.SchoolMeans; SET work.SchoolMeans;
	SchoolN = _FREQ_;	* Saving N per school;
	DROP _TYPE_ _FREQ_;	* Dropping unneeded SAS-created variables;
LABEL	SMfrlunch=		"SMfrlunch: School Mean 0=No, 1=Free/Reduced Lunch"
		SMmath=			"SMmath: School Mean Math Outcome"
		SchoolN=		"SchoolN: # Students Contributing Data";
RUN;

* Merging school means back with individual data;
DATA work.grade10; MERGE work.grade10 work.SchoolMeans; BY schoolID;
	* Selecting only schools with data from at least 30 students;
	IF SchoolN < 31 THEN DELETE;
RUN;

* Outputting table of descriptives;
TITLE "Getting means to center predictors with";
PROC MEANS N MEAN STDDEV MIN MAX DATA=work.grade10; 
	 VAR math frlunch SMmath SMfrlunch SchoolN; 
RUN; TITLE;

* Centering school mean predictor;
DATA grade10; SET grade10;
	SMfrlunch30 = SMfrlunch - .30; LABEL SMfrlunch30= "SMfrlunch30: 0=.30)";
RUN;

******************************************************************************;
****** 					BEGIN EXAMPLE 7 MODELS							******;
******************************************************************************;

* Open output directory to save results to;
ODS RTF FILE="&filesave.\SAS_Example7_Output.rtf" STYLE=HTMLBlue STARTPAGE=NO;

TITLE1 "SAS Model 1: 2-Level Empty Means, Random Intercept for Math Outcome";
PROC MIXED DATA=work.grade10 NOCLPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS schoolID studentID;
	MODEL math = / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT / TYPE=UN SUBJECT=schoolID; RUN;

TITLE1 "SAS Model 2: Adding Fixed Effect of Student Free/Reduced Lunch";
PROC MIXED DATA=work.grade10 NOCLPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS schoolID studentID;
	MODEL math = frlunch / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT / TYPE=UN SUBJECT=schoolID; RUN; 

TITLE1 "SAS Model 3: Adding Fixed Effect of School Proportion Free/Reduced Lunch";
PROC MIXED DATA=work.grade10 NOCLPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS schoolID studentID;
	MODEL math = frlunch SMfrlunch30 
		/ SOLUTION DDFM=Satterthwaite OUTPM=work.LunchSave;
	RANDOM INTERCEPT / TYPE=UN SUBJECT=schoolID; 
    ESTIMATE "FR Lunch Between-School Effect"  frlunch 1 SMfrlunch30 1;
RUN; PROC CORR NOSIMPLE DATA=work.LunchSave; VAR math pred; RUN;

TITLE1 "SAS Model 4: Adding Random Effect of Student Free/Reduced Lunch";
PROC MIXED DATA=work.grade10 NOCLPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS schoolID studentID;
	MODEL math = frlunch SMfrlunch30 
		/ SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT frlunch / G TYPE=UN SUBJECT=schoolID; RUN;

TITLE1 "SAS Model 5: Adding Cross-Level Interaction of Student by School Free/Reduced Lunch";
PROC MIXED DATA=work.grade10 NOCLPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS schoolID studentID;
	MODEL math = frlunch SMfrlunch30 frlunch*SMfrlunch30 
		/ SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT frlunch / G TYPE=UN SUBJECT=schoolID; RUN;

TITLE1 "SAS Model 6: Adding Level-2 Interaction of Quadratic School Free/Reduced Lunch";
PROC MIXED DATA=work.grade10 NOCLPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS schoolID studentID;
	MODEL math = frlunch SMfrlunch30 frlunch*SMfrlunch30 SMfrlunch30*SMfrlunch30
		/ SOLUTION DDFM=Satterthwaite OUTPM=work.TotalSave;
	RANDOM INTERCEPT frlunch / G TYPE=UN SUBJECT=schoolID; 
    ESTIMATE "FR Lunch Between-School Main Effect"  frlunch 1 SMfrlunch30 1;
	ESTIMATE "FR Lunch Between-School Interaction"  frlunch*SMfrlunch30 1 SMfrlunch30*SMfrlunch30 1;
RUN; PROC CORR NOSIMPLE DATA=work.TotalSave; VAR math pred; RUN;

* Close output;
ODS RTF CLOSE;
