* Stop syntax and large ECHOs from printing to output.
SET PRINTBACK=NONE HEADER=NO.

***********************************************************************************.
*******                BEGIN DATA MANIPULATION FOR EXAMPLE 7                *******.
*******                CHANGE "filesave" to your directory                  *******.
***********************************************************************************.

* Define location of files used in code below.
FILE HANDLE filesave /NAME = "C:\Dropbox\Example Data\School Data".
* Import example 7 stacked data.
GET FILE = "filesave/grade10school.sav".
DATASET NAME grade10 WINDOW=FRONT.

VARIABLE LABELS	
  studentID	 "studentID: Student ID number"
		schoolID		 "schoolID: School ID number"
		districtID	"districtID: District ID number"
		frlunch   	"frlunch: 0=No, 1=Free/Reduced Lunch"
		math	     	"math: Math Test Score".
* Selecting complete cases for analysis.
SELECT IF (NMISS(studentID, schoolID, frlunch, math)=0).
EXECUTE.

* Getting school means to use as level-2 predictors.
* SPSS 14+ can merge them back automatically.
	SORT CASES BY schoolID studentID.
	AGGREGATE
  		/OUTFILE=* MODE=ADDVARIABLES
  		/PRESORTED
  		/BREAK = schoolID
  		/SMfrlunch = MEAN(frlunch)
  		/SMmath = MEAN(math)
    /SchoolN = N.

* Labeling new school mean variables.
VARIABLE LABELS	
		SMfrlunch	"SMfrlunch: School Mean 0=No, 1=Free/Reduced Lunch"
  SMmath    "SMmath: School Mean Math"
		SchoolN		 "SchoolN: # Students Contributing Data".

* Selecting schools with data from at least 30 students.
SELECT IF (SchoolN GT 30).

* Descriptive statistics.
DESCRIPTIVES VARIABLES=math frlunch SMfrlunch SchoolN
  /STATISTICS=MEAN STDDEV MIN MAX.

* Centering school mean predictors.
COMPUTE SMfrlunch30 = SMfrlunch - .30. 
VARIABLE LABELS
	 SMfrlunch30   "SMfrlunch30: 0=.30".
EXECUTE.

***********************************************************************************.
*******                       BEGIN EXAMPLE 7 MODELS                        *******.
***********************************************************************************.

* Open output directory.
OUTPUT NAME SPSS_Example7_Output.

ECHO "SPSS Model 0: 1-Level Empty Model for Math Outcome".
MIXED math BY schoolID studentID
	  /METHOD = ML
  	/PRINT  = SOLUTION TESTCOV G
  	/FIXED  = .

ECHO "SPSS Model 1: 2-Level Empty Model for Math Outcome".
MIXED math BY schoolID studentID
	  /METHOD = ML
  	/PRINT  = SOLUTION TESTCOV G
  	/FIXED  =
  	/RANDOM = INTERCEPT | SUBJECT(SchoolID) COVTYPE(UN) .

ECHO "SPSS Model 2: Adding a Fixed Effect of Student Free/Reduced Lunch".
MIXED math BY schoolID studentID WITH frlunch
	  /METHOD = ML
  	/PRINT  = SOLUTION TESTCOV G
  	/FIXED  = frlunch
  	/RANDOM = INTERCEPT | SUBJECT(SchoolID) COVTYPE(UN) .

ECHO "SPSS Model 3: Adding a Fixed Effect of School Proportion Free/Reduced Lunch".
MIXED math BY schoolID studentID WITH frlunch SMfrlunch30
	  /METHOD = ML
  	/PRINT  = SOLUTION TESTCOV G
  	/FIXED  = frlunch SMfrlunch30
   /SAVE   = FIXPRED(lunchpred)
   /TEST   = "FR Lunch Between-School Effect" frlunch 1 SMfrlunch30 1.
CORRELATIONS /VARIABLES = math lunchpred.

ECHO "SPSS Model 4: Adding a Random Effect of Student Free/Reduced Lunch".
MIXED math BY schoolID studentID WITH frlunch SMfrlunch30
	  /METHOD = ML
  	/PRINT  = SOLUTION TESTCOV G
  	/FIXED  = frlunch SMfrlunch30
  	/RANDOM = INTERCEPT frlunch | SUBJECT(SchoolID) COVTYPE(UN) .

ECHO "SPSS Model 5: Adding Cross-Level Interaction of Student by School Free/Reduced Lunch".
MIXED math BY schoolID studentID WITH frlunch SMfrlunch30
	  /METHOD = ML
  	/PRINT  = SOLUTION TESTCOV
  	/FIXED  = frlunch SMfrlunch30 frlunch*SMfrlunch30
  	/RANDOM = INTERCEPT frlunch | SUBJECT(schoolID) COVTYPE(UN).

ECHO "SPSS Model 6: Adding Level-2 Interaction of Quadratic School Free/Reduced Lunch".
MIXED math BY schoolID studentID WITH frlunch SMfrlunch30
	  /METHOD = ML
  	/PRINT  = SOLUTION TESTCOV
  	/FIXED  = frlunch SMfrlunch30 frlunch*SMfrlunch30 SMfrlunch30*SMfrlunch30
  	/RANDOM = INTERCEPT frlunch | SUBJECT(schoolID) COVTYPE(UN)
   /SAVE   = FIXPRED(totalpred)
   /TEST   = "FR Lunch Between-School Main Effect" frlunch 1 SMfrlunch30 1
   /TEST   = "FR Lunch Between-School Interaction" frlunch*SMfrlunch30 1 SMfrlunch30*SMfrlunch30 1.
CORRELATIONS /VARIABLES = math totalpred.

* Close and export output directory.
OUTPUT EXPORT
  /CONTENTS  EXPORT=VISIBLE  LAYERS=VISIBLE  MODELVIEWS=VISIBLE
  /DOC  DOCUMENTFILE="filesave\SPSS_Example7_Output.doc"
     NOTESCAPTIONS=YES  WIDETABLES=WRAP PAGEBREAKS=YES
     PAGESIZE=INCHES(8.5, 11.0)  TOPMARGIN=INCHES(1.0)  BOTTOMMARGIN=INCHES(1.0)
     LEFTMARGIN=INCHES(1.0)  RIGHTMARGIN=INCHES(1.0).
