* Prevent "more" messages from appearing
set more off, permanently
* Control line length
set linesize 150

********************************************************************************
*******             BEGIN DATA MANIPULATION FOR EXAMPLE 7                *******
*******             CHANGE "filesave" to your directory                  *******
********************************************************************************

* Defining global variable for file location to be replaced in code below
global filesave "C:\Dropbox\Example Data\School Data"
 
* Import example 7 stacked data file 
use "$filesave\grade10school.dta", clear

* label existing variables
label variable studentID "studentID: Student ID number"
label variable schoolID  "schoolID: School ID number"
label variable frlunch 	 "frlunch: Student Free/Reduced Lunch 0=No 1=Yes"
label variable math 	 "math: Student Free/Reduced Lunch 0=No 1=Yes"

* get school means of variables and label them
egen SMfrlunch   = mean(frlunch),   by (schoolID)
egen SMmath      = mean(math),      by (schoolID)
label variable SMfrlunch "SMfrlunch: School Mean 0=No, 1=Free/Reduced Lunch"
label variable SMmath	 "SMmath: School Mean Math Outcome"

* get number of students per school
egen SchoolN = count(studentID), by (schoolID)
label variable SchoolN "SchoolN: # Students Contributing Data" 
* then drop schools with <= 30 students
drop if SchoolN < 31

* get means to center with
summarize math frlunch SMmath SMfrlunch SchoolN

* centering school mean predictor
gen SMfrlunch30 = SMfrlunch - .30
label variable SMfrlunch30 "SMfrlunch30: % Students with Free Lunch (0=30%)"

********************************************************************************
******                    BEGIN EXAMPLE 7 MODELS						 *******
********************************************************************************

* Save results to separate file
log using $filesave\STATA_Example7_Output.log, replace name(STATA_Example7)
 
* STATA Model 1: 2-Level Empty Means, Random Intercept for Math Outcome
mixed math  , || schoolID: , 		///
	variance ml covariance(un) residuals(independent),  
	estat ic, n(94),
	estat icc
	
* STATA Model 2: Adding Fixed Effect of Student Free/Reduced Lunch
mixed math c.frlunch, || schoolID: , 	/// 
	variance ml covariance(un) residuals(independent),  
	estat ic, n(94)
	
* STATA Model 3: Adding Fixed Effect of School Proportion Free/Reduced Lunch
mixed math c.frlunch c.SMfrlunch30, || schoolID: ,  /// 
	variance ml covariance(un) residuals(independent),  
	estat ic, n(94), 
	predict lunchpred,				  		// save fixed-effect predicted outcomes
	estimates store FixFRLunch,		  		// save LL for LRT
	lincom 1*c.frlunch + 1*c.SMfrlunch30    // FR lunch between-school effect
corr math lunchpred					  	    // calculate total R2
	
* STATA Model 4: Adding Random Effect of Student Free/Reduced Lunch
mixed math c.frlunch c. SMfrlunch30, || schoolID: frlunch,  /// 
	variance ml covariance(un) residuals(independent),  
	estat recovariance, relevel(schoolID),
	estat ic, n(94),
	estimates store RandFRLunch			// save LL for LRT
	lrtest RandFRLunch FixFRLunch   	// LRT against fixed effect model

* STATA Model 5: Adding Cross-Level Interaction of Student by School Free/Reduced Lunch
mixed math c.frlunch c.SMfrlunch30 c.frlunch#c.SMfrlunch30, ///
	|| schoolID: frlunch, variance ml covariance(un) residuals(independent),  
	estat ic, n(94)

* STATA Model 6: Adding Level-2 Interaction of Quadratic School Free/Reduced Lunch
mixed math c.frlunch c.SMfrlunch30 c.frlunch#c.SMfrlunch30 c.SMfrlunch30#c.SMfrlunch30, ///
	|| schoolID: frlunch, variance ml covariance(un) residuals(independent),  
	estat ic, n(94),
	predict totalpred,					   			// save fixed-effect predicted outcomes
lincom 1*c.frlunch + 1*c.SMfrlunch30  	   		                  // FR lunch BS main effect
lincom 1*c.frlunch#c.SMfrlunch30 + 1*c.SMfrlunch30#c.SMfrlunch30  // FR lunch BS interaction
margins, at(c.frlunch=(0 1) c.SMfrlunch30=(-.2 0 .2 .4)) vsquish      // create predicted values
marginsplot, noci name(predicted_lunch, replace) xdimension(frlunch)  // plot predicted, no CI 
corr math totalpred					       						      // calculate total R2

* Close log	
log close STATA_Example7
